#!/bin/sh
#version 1.1
set -u

PRODUCT=CPE
PRODUCT_LOWCASE=cpe
h3c_sda0path=/mnt/sda0\:/
upgrade_path=/mnt/sda0\:/cpe_upgrade
download_path=/mnt/sda0\:/cpe_upgrade/download
version_path=/etc/cpeagent/
conf_file=/etc/cpeagent/cpeagent.conf
bak_conf_file=/etc/cpeagent/cpeagent.conf.upgradebak

logfile=/mnt/sda0\:/logfile/logfile.log
target="version"
patch_target_type=""
target_name=""
bak_packet=""
result_id=""
ret=0

log()
{
    echo `date` "upgrade:" $@ >> $logfile
}

#write_upgrade_result_conf $1=success/failure
write_upgrade_result_conf()
{
    rm $bak_conf_file -f
    cp $conf_file $bak_conf_file -f
    if [ $? -eq 0 ];then
        sed -i "/upgraderesult/d" $bak_conf_file
        sed -i "/upgradeID/d" $bak_conf_file
        echo "upgraderesult=$1"  >> $bak_conf_file
        echo "upgradeID=${result_id}"  >> $bak_conf_file
        cp $bak_conf_file $conf_file -f
    fi
}

upgrade_product_version()
{
    target_name=`ls ${download_path} | grep -E  '\.ipe$|\.tar\.gz$'`
    if [ -z "$target_name" ]; then
    {
        log "UPGRADE version failed, could't find upgrade target"
        ret=-1
        return $ret
    }
    fi

    target_name=`ls ${download_path} | grep '\.ipe$'`
    if [ -n "$target_name" ]; then
        rm -rf $upgrade_path/*.tar.gz
        rm -rf $h3c_sda0path/*.bin
        rm -rf $h3c_sda0path/*.ipe
        mv ${download_path}/${target_name} $h3c_sda0path
        /bin/appex/comwarecmd ipe $target_name >> $logfile
        ret=$?
        rm -rf $h3c_sda0path/*.ipe
    else
        target_name=`ls ${download_path} | grep '\.tar\.gz$'`
        #兼容性检查 todo
        rm -rf $upgrade_path/*.tar.gz*
        mv ${download_path}/${target_name} $upgrade_path
    fi

    if [[ $ret -eq 0 ]]; then
        log "install $target_name success "
    else
        log "install $target_name failed"
    fi
    return $ret
}

upgrade_version()
{
    log "----------------$(date)--------------------"
    log "Version upgrade, target=${target_name} result_id=${result_id}"
    if [ ! -f ${download_path}/${target_name} ];then
        log "Could't find $target_name in directory ${download_path}, upgrade ${result_id} failed"
        /bin/appex/cpeagent upgradeFailed
        exit
    fi

    upgrade_product_version

    if [[ $? -eq 0 ]];then
        log "Upgrade ${target_name} upgradeId ${result_id} success"
        write_upgrade_result_conf "success"
        /bin/appex/comwarecmd reboot
        exit
    else
        write_upgrade_result_conf "failure"
    fi
}

help()
{
    echo "Usage: $0 --target=<patch/version> --target_name=H3cComware.tar.gz --result_id=xxxx"
    echo "      --target/-t         : Target  patch/version"
    echo "      --target_name/-tn   : Upgrade target name, e.g H3cComware.tar.gz"
    echo "      --result_id/-r      : upgrade Id"
    echo "./LW_update.sh -t=version -tn=H3cComware.tar.gz -r=2"
}

for opt in ${@};
do
    str="="
    result=$(echo $opt | grep "$str")
    if [ -n $result ]; then
        k=${opt%=*}
        v=${opt#*=}
    else
        k=${opt}
    fi

    case ${k} in
        "--target"|"-t") target=${v};;
        "--target_name"|"-tn") target_name=${v};;
        "--result_id"|"-r") result_id=${v};;
        *) echo "${opt} is error";;
    esac
done

if [ $# -lt 3 ];then
    target="manual_version"
else
    [[ -z $target || -z $target_name || -z $result_id ]] && {
        help
        exit 1
    }
fi

if [ ${target} == "version" ]; then
    upgrade_version

else
    log "----------------$(date)--------------------"
    log "Unsupported target ${target} result_id=${result_id}"
    /bin/appex/cpeagent upgradeFailed
fi
